@echo off
@rem **********************************************************************************
@rem 
@rem USB Serial Driver Installation Batch File
@rem 
@rem Version:
@rem 	1.2
@rem
@rem Usage:
@rem 	_install.bat [/Arg] [NUVUSD_DRIVERPATH]
@rem 
@rem Arg:
@rem	/i to install control, enum and cdc drivers 
@rem	/p to preinstall control, enum and cdc and rescan USB
@rem 	/u to uninstall control enum and cdc drivers
@rem
@rem Examples:
@rem    _install /i .\x86   	'install control 
@rem    _install /p .\x86	'install control and pre-install enum and cdc 
@rem    _install /u 		'uninstall all 
@rem
@rem Defaults (override defaults by seting the following environmental vars or using command line args):
@rem    NUVUSD_ACTION- 'install' to install (control only), 'preinstall' to install control and pre-install enum and cdc, 
@rem 			'uninstall' to uninstall
@rem    NUVUSD_DRIVERPATH - Path to the driver
@rem 	NUVUSD_WDREGEXE - Name of wdreg util, wreg.exe or wdreg_gui.exe 
@rem 	NUVUSD_SILENT - Set to 'silent' to specify silent install
@rem
@rem **********************************************************************************


@rem **********************************************************************************
@rem If environmental vars are not set, set them to defaults
@rem **********************************************************************************
set NUVUSD_VER=1.3
if ""%NUVUSD_WDREGEXE%""=="""" set NUVUSD_WDREGEXE=wdreg.exe
if ""%NUVUSD_DRIVERPATH%""=="""" set NUVUSD_DRIVERPATH=.\x86
if ""%NUVUSD_ACTION%""=="""" set NUVUSD_ACTION=preinstall
if ""%NUVUSD_SILENT%""=="""" set NUVUSD_SILENT=
if ""%NUVUSD_CAPTURESETUPAPILOG%""=="""" set NUVUSD_CAPTURESETUPAPILOG=1
if ""%NUVUSD_RESCAN%""=="""" set NUVUSD_RESCAN=1

@rem **********************************************************************************
@rem Process command line args
@rem **********************************************************************************

@rem Check command line args
if ""%1""=="""" goto COMMANDLINEOK
if ""%1""==""/i"" goto COMMANDLINEOK
if ""%1""==""/u"" goto COMMANDLINEOK
if ""%1""==""/p"" goto COMMANDLINEOK
if ""%1""==""/si"" goto COMMANDLINEOK
if ""%1""==""/su"" goto COMMANDLINEOK
if ""%1""==""/sp"" goto COMMANDLINEOK
@echo Command line (%1) incorrect, validate the options are correct and re-run the install.
goto END
:COMMANDLINEOK

@rem Make sure to reset environmental vars when command line changes incase user runs command multible time from the same 
@rem command prompt

if ""%1""=="""" goto DONESETARGS
if ""%1""==""/i"" set NUVUSD_ACTION=install
if ""%1""==""/u"" set NUVUSD_ACTION=uninstall
if ""%1""==""/p"" set NUVUSD_ACTION=preinstall
if ""%1""==""/i"" set NUVUSD_RESCAN=0
if ""%1""==""/u"" set NUVUSD_RESCAN=0
if ""%1""==""/p"" set NUVUSD_RESCAN=1
if ""%1""==""/i"" set NUVUSD_SILENT=
if ""%1""==""/u"" set NUVUSD_SILENT=
if ""%1""==""/p"" set NUVUSD_SILENT=
if ""%1""==""/i"" set NUVUSD_WDREGEXE=wdreg.exe
if ""%1""==""/u"" set NUVUSD_WDREGEXE=wdreg.exe
if ""%1""==""/p"" set NUVUSD_WDREGEXE=wdreg.exe

if ""%2""=="""" goto DONESETARGS
set NUVUSD_DRIVERPATH=%2
:DONESETARGS

@rem **********************************************************************************
@rem Check Driver Location
@rem **********************************************************************************
if exist "%NUVUSD_DRIVERPATH%\%NUVUSD_WDREGEXE%" goto DRIVERPATHOK
@echo Driver path (%NUVUSD_DRIVERPATH%) incorrect, validate the path is correct and re-run the install.
goto END
:DRIVERPATHOK

@rem **********************************************************************************
@rem Run wdreg.exe based on the action specified
@rem **********************************************************************************
if ""%NUVUSD_ACTION%""==""install"" goto INSTALL
if ""%NUVUSD_ACTION%""==""preinstall"" goto PREINSTALL
if ""%NUVUSD_ACTION%""==""uninstall"" goto UNINSTALL
@echo Action (%NUVUSD_ACTION%) incorrect, validate the options are correct and re-run the install.
goto END

@rem **********************************************************************************
@rem Install/Preinstall driver
@rem **********************************************************************************
:PREINSTALL
:INSTALL
@set LOGFILE=.\Install.log
if exist %LOGFILE% del %LOGFILE%
@echo. > %LOGFILE%

@rem copy usbser.sys to system32/drivers 
if ""%NUVUSD_DRIVERPATH%""=="".\x86"" copy "%NUVUSD_DRIVERPATH%\usbser.sys" %SystemRoot%\system32\drivers>nul


@echo ************************************************************ >> %LOGFILE%
@echo WDREG LOG - %date% %time% >> %LOGFILE%
@echo ************************************************************ >> %LOGFILE%
@echo NUVUSD_VER=%NUVUSD_VER% >> %LOGFILE%
@echo ARG[1]=%1 >> %LOGFILE%
@echo ARG[2]=%2 >> %LOGFILE%
@echo NUVUSD_WDREGEXE=%NUVUSD_WDREGEXE% >> %LOGFILE%
@echo NUVUSD_DRIVERPATH=%NUVUSD_DRIVERPATH% >> %LOGFILE%
@echo NUVUSD_ACTION=%NUVUSD_ACTION% >> %LOGFILE%
@echo NUVUSD_SILENT=%NUVUSD_SILENT% >> %LOGFILE%
@echo NUVUSD_INSTALLCONTROL=%NUVUSD_INSTALLCONTROL% >> %LOGFILE%
@echo NUVUSD_INSTALLENUM=%NUVUSD_INSTALLENUM% >> %LOGFILE%
@echo NUVUSD_INSTALLCDC=%NUVUSD_INSTALLCDC% >> %LOGFILE%
@echo NUVUSD_CAPTURESETUPAPILOG=%NUVUSD_CAPTURESETUPAPILOG% >> %LOGFILE%
@echo NUVUSD_RESCAN=%NUVUSD_RESCAN% >> %LOGFILE%

@rem 'preinstall' is used.

for /f "delims=|" %%f in ('dir /b "%NUVUSD_DRIVERPATH%\NuvotonCDC.inf"') do ^
"%NUVUSD_DRIVERPATH%\%NUVUSD_WDREGEXE%" -inf "%NUVUSD_DRIVERPATH%\%%f" %NUVUSD_SILENT% -log "%LOGFILE%" install

goto SKIPUNINSTALL

@rem **********************************************************************************
@rem Uninstall driver
@rem **********************************************************************************
:UNINSTALL
@set LOGFILE=.\Uninstall.log

@echo. > %LOGFILE%

@echo ************************************************************ >> %LOGFILE%
@echo WDREG LOG - %date% %time% >> %LOGFILE%
@echo ************************************************************ >> %LOGFILE%
@echo NUVUSD_VER=%NUVUSD_VER% >> %LOGFILE%
@echo ARG[1]=%1 >> %LOGFILE%
@echo ARG[2]=%2 >> %LOGFILE%
@echo NUVUSD_WDREGEXE=%NUVUSD_WDREGEXE% >> %LOGFILE%
@echo NUVUSD_DRIVERPATH=%NUVUSD_DRIVERPATH% >> %LOGFILE%
@echo NUVUSD_ACTION=%NUVUSD_ACTION% >> %LOGFILE%
@echo NUVUSD_SILENT=%NUVUSD_SILENT% >> %LOGFILE%
@echo NUVUSD_INSTALLCONTROL=%NUVUSD_INSTALLCONTROL% >> %LOGFILE%
@echo NUVUSD_INSTALLENUM=%NUVUSD_INSTALLENUM% >> %LOGFILE%
@echo NUVUSD_INSTALLCDC=%NUVUSD_INSTALLCDC% >> %LOGFILE%
@echo NUVUSD_CAPTURESETUPAPILOG=%NUVUSD_CAPTURESETUPAPILOG% >> %LOGFILE%
@echo NUVUSD_RESCAN=%NUVUSD_RESCAN% >> %LOGFILE%

for /f "delims=|" %%f in ('dir /b %NUVUSD_DRIVERPATH%\NuvotonCDC.inf') do ^
"%NUVUSD_DRIVERPATH%\%NUVUSD_WDREGEXE%" -inf "%NUVUSD_DRIVERPATH%\%%f" %NUVUSD_SILENT% -log %LOGFILE% %NUVUSD_ACTION%

:SKIPUNINSTALL

@rem **********************************************************************************
@rem Rescan, needed if driver is preinstall and device is already connected.   Much faster to preinstall and rescan 
@rem than to install, install searches for every device in inf.
@rem **********************************************************************************
if ""%NUVUSD_RESCAN%""==""0"" GOTO SKIPHSMUSDRESCAN
"%NUVUSD_DRIVERPATH%\%NUVUSD_WDREGEXE%" -rescan USB %NUVUSD_SILENT% -log %LOGFILE% %NUVUSD_ACTION%
:SKIPHSMUSDRESCAN

@rem **********************************************************************************
@rem Copy SetupAPI log to install/uninstall log
@rem **********************************************************************************
if ""%NUVUSD_CAPTURESETUPAPILOG%""==""0"" GOTO END
@echo. >> %LOGFILE% 
if exist "%SystemRoot%\setupapi.log" @echo ************************************************************ >> %LOGFILE%
if exist "%SystemRoot%\setupapi.log" @echo SETUPAPI LOG >> %LOGFILE%
if exist "%SystemRoot%\setupapi.log" @echo ************************************************************ >> %LOGFILE%
if exist "%SystemRoot%\inf\setupapi.dev.log" @echo ************************************************************ >> %LOGFILE%
if exist "%SystemRoot%\inf\setupapi.dev.log" @echo SETUPAPI LOG >> %LOGFILE%
if exist "%SystemRoot%\inf\setupapi.dev.log" @echo ************************************************************ >> %LOGFILE%
if exist "%SystemRoot%\setupapi.log" @type %SystemRoot%\setupapi.log >> %LOGFILE%
if exist "%SystemRoot%\inf\setupapi.dev.log" @type %SystemRoot%\inf\setupapi.dev.log >> %LOGFILE%


:END